@@ -7,28 +7,20 @@ if(tenant == "" || app == "")
 if(!interactive())
     skip("OneDrive for Business tests skipped: must be in interactive session")
 
-tok <- try(AzureAuth::get_azure_token(
-    c("https://graph.microsoft.com/.default",
-      "openid",
-      "offline_access"),
-    tenant=tenant, app=app, version=2),
-    silent=TRUE)
-if(inherits(tok, "try-error"))
+tok <- get_test_token(tenant, app, c("Files.ReadWrite.All", "User.Read"))
+if(is.null(tok))
     skip("OneDrive for Business tests skipped: no access to tenant")
 
-gr <- AzureGraph::ms_graph$new(token=tok)
 drv <- try(call_graph_endpoint(tok, "me/drive"), silent=TRUE)
 if(inherits(drv, "try-error"))
     skip("OneDrive for Business tests skipped: service not available")
 
+od <- ms_drive$new(tok, tenant, drv)
+
 test_that("OneDrive for Business works",
 {
-    od <- get_business_onedrive(tenant=tenant)
     expect_is(od, "ms_drive")
 
-    od2 <- get_business_onedrive(tenant=tenant, app=app)
-    expect_is(od2, "ms_drive")
-
     lst <- od$list_items()
     expect_is(lst, "data.frame")
 
@@ -67,27 +59,38 @@ test_that("OneDrive for Business works",
 
 test_that("Drive item methods work",
 {
-    od <- get_business_onedrive(tenant=tenant, app=app)
-
     root <- od$get_item("/")
     expect_is(root, "ms_drive_item")
 
+    rootp <- root$get_parent_folder()
+    expect_is(rootp, "ms_drive_item")
+    expect_equal(rootp$properties$name, "root")
+
     tmpname1 <- make_name(10)
     folder1 <- root$create_folder(tmpname1)
     expect_is(folder1, "ms_drive_item")
     expect_true(folder1$is_folder())
 
+    folder1p <- folder1$get_parent_folder()
+    expect_equal(rootp$properties$name, "root")
+
     tmpname2 <- make_name(10)
     folder2 <- folder1$create_folder(tmpname2)
     expect_is(folder2, "ms_drive_item")
     expect_true(folder2$is_folder())
 
+    folder2p <- folder2$get_parent_folder()
+    expect_equal(folder2p$properties$name, folder1$properties$name)
+
     src <- write_file()
     expect_silent(file1 <- root$upload(src))
     expect_is(file1, "ms_drive_item")
     expect_false(file1$is_folder())
     expect_error(file1$create_folder("bad"))
 
+    file1p <- file1$get_parent_folder()
+    expect_equal(file1p$properties$name, "root")
+
     file1_0 <- root$get_item(basename(src))
     expect_is(file1_0, "ms_drive_item")
     expect_false(file1_0$is_folder())
@@ -100,6 +103,9 @@ test_that("Drive item methods work",
     expect_silent(file2 <- folder1$upload(src))
     expect_is(file2, "ms_drive_item")
 
+    file2p <- file2$get_parent_folder()
+    expect_equal(file2p$properties$name, folder1$properties$name)
+
     dest2 <- tempfile()
     expect_silent(file2$download(dest2))
     expect_true(files_identical(src, dest2))
@@ -139,8 +145,6 @@ test_that("Drive item methods work",
 
 test_that("Methods work with filenames with special characters",
 {
-    od <- get_business_onedrive(tenant=tenant)
-
     test_name <- paste(make_name(5), "plus spaces and áccénts")
     src <- write_file(fname=file.path(tempdir(), test_name))
 
@@ -153,8 +157,6 @@ test_that("Methods work with filenames with special characters",
 
 test_that("Nested folder creation/deletion works",
 {
-    od <- get_business_onedrive()
-
     f1 <- make_name(10)
     f2 <- make_name(10)
     f3 <- make_name(10)
